@@ -15,7 +15,7 @@ ffmpeg -y -nostdin \
 	-pix_fmt:0 yuv420p -profile:v:0 main -g:v:0 25 \
 	-preset:v:0 veryfast \
 	\
-	-ac 1 -c:a libfdk_aac -b:a 96k -ar 44100 \
+	-ac 1 -c:a aac -b:a 96k -ar 44100 \
 	-map 0:a -filter:a:0 pan=mono:c0=FL \
 	-ac:a:2 2 \
 	\
