@@ -61,12 +61,25 @@ class LoopSource(object):
 def main():
     signal.signal(signal.SIGINT, signal.SIG_DFL)
 
-    config = os.path.join(os.path.dirname(os.path.realpath(__file__)),
-                          '../config.sh')
-    with open(config, 'r') as config:
-        lines = [line.strip() for line in config if line[0] != '#']
-        pairs = [line.split('=', 1) for line in lines]
-        settings = {pair[0]: pair[1] for pair in pairs}
+    settings = {}
+
+    for prefix in ['default-', '']:
+        config = os.path.join(os.path.dirname(os.path.realpath(__file__)),
+                              '..', '{}config.sh'.format(prefix))
+        if not os.path.exists(config):
+            continue
+
+        with open(config, 'r') as config:
+            lines = [line.strip() for line in config if line[0] != '#']
+            pairs = [line.split('=', 1) for line in lines]
+            for pair in pairs:
+                settings[pair[0]] = pair[1]
+
+    if not ('FRAMERATE' in settings and
+            'WIDTH' in settings and
+            'HEIGHT' in settings):
+        print("Config needs: FRAMERATE, WIDTH, and HEIGHT")
+        return
 
     src = LoopSource(settings)
 
