@@ -1,4 +1,5 @@
 import logging
+
 from gi.repository import Gst
 
 from lib.config import Config
@@ -7,7 +8,6 @@ from lib.clock import Clock
 
 
 class AVRawOutput(TCPMultiConnection):
-
     def __init__(self, channel, port):
         self.log = logging.getLogger('AVRawOutput[{}]'.format(channel))
         super().__init__(port)
@@ -19,12 +19,24 @@ class AVRawOutput(TCPMultiConnection):
             {vcaps} !
             queue !
             mux.
+        """.format(
+            channel=self.channel,
+            vcaps=Config.get('mix', 'videocaps'),
+        )
 
-            interaudiosrc channel=audio_{channel} !
-            {acaps} !
-            queue !
-            mux.
+        for audiostream in range(0, Config.getint('mix', 'audiostreams')):
+            pipeline += """
+                interaudiosrc channel=audio_{channel}_stream{audiostream} !
+                {acaps} !
+                queue !
+                mux.
+            """.format(
+                channel=self.channel,
+                acaps=Config.get('mix', 'audiocaps'),
+                audiostream=audiostream,
+            )
 
+        pipeline += """
             matroskamux
                 name=mux
                 streamable=true
@@ -36,10 +48,7 @@ class AVRawOutput(TCPMultiConnection):
                 sync-method=next-keyframe
                 name=fd
         """.format(
-            channel=self.channel,
-            acaps=Config.get('mix', 'audiocaps'),
-            vcaps=Config.get('mix', 'videocaps'),
-            buffers_max=Config.get('output-buffers', channel, fallback=500)
+            buffers_max=Config.getint('output-buffers', channel, fallback=500)
         )
         self.log.debug('Creating Output-Pipeline:\n%s', pipeline)
         self.outputPipeline = Gst.parse_launch(pipeline)
