@@ -1,9 +1,8 @@
 import logging
-from gi.repository import Gst
 
 # import library components
 from lib.config import Config
-from lib.avsource import AVSource
+from lib.sources import spawn_source
 from lib.avrawoutput import AVRawOutput
 from lib.avpreviewoutput import AVPreviewOutput
 from lib.videomix import VideoMix
@@ -30,24 +29,32 @@ class Pipeline(object):
         self.previews = []
         self.sbsources = []
 
-        self.log.info('Creating %u Creating AVSources: %s', len(names), names)
+        self.log.info('Creating %u AVSources: %s', len(names), names)
         for idx, name in enumerate(names):
             port = 10000 + idx
-            self.log.info('Creating AVSource %s at tcp-port %u', name, port)
 
-            outputs = [name + '_mixer', name + '_mirror']
+            outputs = [name + '_mixer']
             if Config.getboolean('previews', 'enabled'):
                 outputs.append(name + '_preview')
 
-            source = AVSource(name, port, outputs=outputs)
+            if Config.getboolean('mirrors', 'enabled'):
+                outputs.append(name + '_mirror')
+
+            if Config.has_option('mix', 'slides_source_name') and \
+                    Config.get('mix', 'slides_source_name') == name:
+                outputs.append('slides_stream-blanker')
+
+            source = spawn_source(name, port, outputs=outputs)
+            self.log.info('Creating AVSource %s as %s', name, source)
             self.sources.append(source)
 
-            port = 13000 + idx
-            self.log.info('Creating Mirror-Output for AVSource %s '
-                          'at tcp-port %u', name, port)
+            if Config.getboolean('mirrors', 'enabled'):
+                port = 13000 + idx
+                self.log.info('Creating Mirror-Output for AVSource %s '
+                              'at tcp-port %u', name, port)
 
-            mirror = AVRawOutput('%s_mirror' % name, port)
-            self.mirrors.append(mirror)
+                mirror = AVRawOutput('%s_mirror' % name, port)
+                self.mirrors.append(mirror)
 
             if Config.getboolean('previews', 'enabled'):
                 port = 14000 + idx
@@ -60,18 +67,12 @@ class Pipeline(object):
         self.log.info('Creating Videmixer')
         self.vmix = VideoMix()
 
-        # check if there is an audio source preconfigured
-        try:
-            audiosource = names.index(Config.get('mix', 'audiosource'))
-        except:
-            audiosource = 0
-
         self.log.info('Creating Audiomixer')
-        self.amix = AudioMix(audiosource)
+        self.amix = AudioMix()
 
         port = 16000
-        self.log.info('Creating Mixer-Background VSource at tcp-port %u', port)
-        self.bgsrc = AVSource('background', port, has_audio=False)
+        self.bgsrc = spawn_source('background', port, has_audio=False)
+        self.log.info('Creating Mixer-Background VSource as %s', self.bgsrc)
 
         port = 11000
         self.log.info('Creating Mixer-Output at tcp-port %u', port)
@@ -79,8 +80,8 @@ class Pipeline(object):
 
         if Config.getboolean('previews', 'enabled'):
             port = 12000
-            self.log.info('Creating Preview-Output for AVSource %s '
-                          'at tcp-port %u', name, port)
+            self.log.info('Creating Preview-Output for Mix'
+                          'at tcp-port %u', port)
 
             self.mixpreview = AVPreviewOutput('mix_preview', port)
 
@@ -92,23 +93,33 @@ class Pipeline(object):
                                    'StreamBlanker disabled!')
             for idx, name in enumerate(names):
                 port = 17000 + idx
-                self.log.info('Creating StreamBlanker VSource %s '
-                              'at tcp-port %u', name, port)
 
-                source = AVSource('{}_streamblanker'.format(name), port,
-                                  has_audio=False)
+                source = spawn_source('stream-blanker-{}'.format(name), port,
+                                      has_audio=False)
+                self.log.info('Creating StreamBlanker VSource %s as %s',
+                              name, source)
                 self.sbsources.append(source)
 
             port = 18000
             self.log.info('Creating StreamBlanker ASource at tcp-port %u',
                           port)
 
-            source = AVSource('streamblanker', port, has_video=False)
+            source = spawn_source('stream-blanker',
+                                  port,
+                                  has_video=False,
+                                  force_num_streams=1)
             self.sbsources.append(source)
 
-        self.log.info('Creating StreamBlanker')
-        self.streamblanker = StreamBlanker()
+            self.log.info('Creating StreamBlanker')
+            self.streamblanker = StreamBlanker()
 
-        port = 15000
-        self.log.info('Creating StreamBlanker-Output at tcp-port %u', port)
-        self.streamout = AVRawOutput('streamblanker_out', port)
+            port = 15000
+            self.log.info('Creating StreamBlanker-Output at tcp-port %u', port)
+            self.streamout = AVRawOutput('stream-blanker_out', port)
+
+            if Config.has_option('mix', 'slides_source_name'):
+                port = 15001
+                self.log.info(
+                    'Creating SlideStreamBlanker-Output at tcp-port %u', port)
+                self.slides_streamout = AVRawOutput(
+                    'slides_stream-blanker_out', port)
