@@ -1,7 +1,9 @@
 import logging
-from gi.repository import Gst
+from configparser import NoOptionError
 from enum import Enum, unique
 
+from gi.repository import Gst
+
 from lib.config import Config
 from lib.clock import Clock
 
@@ -15,18 +17,25 @@ class CompositeModes(Enum):
 
 
 class PadState(object):
-
     def __init__(self):
         self.reset()
 
     def reset(self):
         self.alpha = 1.0
+
+        self.zorder = 1
+
         self.xpos = 0
         self.ypos = 0
-        self.zorder = 1
+
         self.width = 0
         self.height = 0
 
+        self.croptop = 0
+        self.cropleft = 0
+        self.cropbottom = 0
+        self.cropright = 0
+
 
 class VideoMix(object):
     log = logging.getLogger('VideoMix')
@@ -60,13 +69,14 @@ class VideoMix(object):
 
         if Config.getboolean('stream-blanker', 'enabled'):
             pipeline += """
-                tee. ! queue ! intervideosink channel=video_mix_streamblanker
+                tee. ! queue ! intervideosink channel=video_mix_stream-blanker
             """
 
         for idx, name in enumerate(self.names):
             pipeline += """
                 intervideosrc channel=video_{name}_mixer !
                 {caps} !
+                videocrop name=video_{idx}_cropper !
                 mix.
             """.format(
                 name=name,
@@ -102,7 +112,7 @@ class VideoMix(object):
         self.applyMixerState()
 
         bgMixerpad = (self.mixingPipeline.get_by_name('mix')
-                                         .get_static_pad('sink_0'))
+                      .get_static_pad('sink_0'))
         bgMixerpad.set_property('zorder', 0)
 
         self.log.debug('Launching Mixing-Pipeline')
@@ -151,31 +161,38 @@ class VideoMix(object):
         try:
             gutter = Config.getint('side-by-side-equal', 'gutter')
             self.log.debug('Gutter configured to %u', gutter)
-        except:
+        except NoOptionError:
             gutter = int(width / 100)
             self.log.debug('Gutter calculated to %u', gutter)
 
-        targetWidth = int((width - gutter) / 2)
+        try:
+            border = Config.getint('side-by-side-equal', 'border')
+            self.log.debug('border configured to %u', border)
+        except NoOptionError:
+            border = 0
+            self.log.debug('border calculated to %u', border)
+
+        targetWidth = int((width - gutter - border - border) / 2)
         targetHeight = int(targetWidth / width * height)
 
         self.log.debug('Video-Size calculated to %ux%u',
                        targetWidth, targetHeight)
 
-        xa = 0
-        xb = width - targetWidth
-        y = (height - targetHeight) / 2
+        xa = border
+        xb = width - targetWidth - border
+        y = int((height - targetHeight) / 2)
 
         try:
             ya = Config.getint('side-by-side-equal', 'atop')
             self.log.debug('A-Video Y-Pos configured to %u', ya)
-        except:
+        except NoOptionError:
             ya = y
             self.log.debug('A-Video Y-Pos calculated to %u', ya)
 
         try:
             yb = Config.getint('side-by-side-equal', 'btop')
             self.log.debug('B-Video Y-Pos configured to %u', yb)
-        except:
+        except NoOptionError:
             yb = y
             self.log.debug('B-Video Y-Pos calculated to %u', yb)
 
@@ -189,12 +206,12 @@ class VideoMix(object):
             if idx == self.sourceA:
                 pad.xpos = xa
                 pad.ypos = ya
-                pad.zorder = 1
+                pad.zorder = 2
 
             elif idx == self.sourceB:
                 pad.xpos = xb
                 pad.ypos = yb
-                pad.zorder = 2
+                pad.zorder = 1
 
             else:
                 pad.alpha = 0
@@ -211,7 +228,7 @@ class VideoMix(object):
                                                 'asize').split('x', 1)]
             self.log.debug('A-Video-Size configured to %ux%u',
                            asize[0], asize[1])
-        except:
+        except NoOptionError:
             asize = [
                 int(width / 1.25),  # 80%
                 int(height / 1.25)  # 80%
@@ -219,12 +236,22 @@ class VideoMix(object):
             self.log.debug('A-Video-Size calculated to %ux%u',
                            asize[0], asize[1])
 
+        try:
+            acrop = [int(i) for i in Config.get('side-by-side-preview',
+                                                'acrop').split('/', 3)]
+            self.log.debug('A-Video-Cropping configured to %u/%u/%u/%u',
+                           acrop[0], acrop[1], acrop[2], acrop[3])
+        except NoOptionError:
+            acrop = [0, 0, 0, 0]
+            self.log.debug('A-Video-Cropping calculated to %u/%u/%u/%u',
+                           acrop[0], acrop[1], acrop[2], acrop[3])
+
         try:
             apos = [int(i) for i in Config.get('side-by-side-preview',
                                                'apos').split('/', 1)]
             self.log.debug('A-Video-Position configured to %u/%u',
                            apos[0], apos[1])
-        except:
+        except NoOptionError:
             apos = [
                 int(width / 100),  # 1%
                 int(width / 100)  # 1%
@@ -237,7 +264,7 @@ class VideoMix(object):
                                                 'bsize').split('x', 1)]
             self.log.debug('B-Video-Size configured to %ux%u',
                            bsize[0], bsize[1])
-        except:
+        except NoOptionError:
             bsize = [
                 int(width / 4),  # 25%
                 int(height / 4)  # 25%
@@ -245,12 +272,22 @@ class VideoMix(object):
             self.log.debug('B-Video-Size calculated to %ux%u',
                            bsize[0], bsize[1])
 
+        try:
+            bcrop = [int(i) for i in Config.get('side-by-side-preview',
+                                                'bcrop').split('/', 3)]
+            self.log.debug('B-Video-Cropping configured to %u/%u/%u/%u',
+                           bcrop[0], bcrop[1], bcrop[2], bcrop[3])
+        except NoOptionError:
+            bcrop = [0, 0, 0, 0]
+            self.log.debug('B-Video-Cropping calculated to %u/%u/%u/%u',
+                           bcrop[0], bcrop[1], bcrop[2], bcrop[3])
+
         try:
             bpos = [int(i) for i in Config.get('side-by-side-preview',
                                                'bpos').split('/', 1)]
             self.log.debug('B-Video-Position configured to %u/%u',
                            bpos[0], bpos[1])
-        except:
+        except NoOptionError:
             bpos = [
                 width - int(width / 100) - bsize[0],
                 height - int(width / 100) - bsize[1]  # 1%
@@ -264,11 +301,19 @@ class VideoMix(object):
 
             if idx == self.sourceA:
                 pad.xpos, pad.ypos = apos
+                pad.croptop, \
+                    pad.cropleft, \
+                    pad.cropbottom, \
+                    pad.cropright = acrop
                 pad.width, pad.height = asize
                 pad.zorder = 1
 
             elif idx == self.sourceB:
                 pad.xpos, pad.ypos = bpos
+                pad.croptop, \
+                    pad.cropleft, \
+                    pad.cropbottom, \
+                    pad.cropright = bcrop
                 pad.width, pad.height = bsize
                 pad.zorder = 2
 
@@ -287,7 +332,7 @@ class VideoMix(object):
                                                   'pipsize').split('x', 1)]
             self.log.debug('PIP-Size configured to %ux%u',
                            pipsize[0], pipsize[1])
-        except:
+        except NoOptionError:
             pipsize = [
                 int(width / 4),  # 25%
                 int(height / 4)  # 25%
@@ -295,12 +340,22 @@ class VideoMix(object):
             self.log.debug('PIP-Size calculated to %ux%u',
                            pipsize[0], pipsize[1])
 
+        try:
+            pipcrop = [int(i) for i in Config.get('picture-in-picture',
+                                                  'pipcrop').split('/', 3)]
+            self.log.debug('PIP-Video-Cropping configured to %u/%u/%u/%u',
+                           pipcrop[0], pipcrop[1], pipcrop[2], pipcrop[3])
+        except NoOptionError:
+            pipcrop = [0, 0, 0, 0]
+            self.log.debug('PIP-Video-Cropping calculated to %u/%u/%u/%u',
+                           pipcrop[0], pipcrop[1], pipcrop[2], pipcrop[3])
+
         try:
             pippos = [int(i) for i in Config.get('picture-in-picture',
                                                  'pippos').split('/', 1)]
             self.log.debug('PIP-Position configured to %u/%u',
                            pippos[0], pippos[1])
-        except:
+        except NoOptionError:
             pippos = [
                 width - pipsize[0] - int(width / 100),  # 1%
                 height - pipsize[1] - int(width / 100)  # 1%
@@ -326,8 +381,10 @@ class VideoMix(object):
         for idx, state in enumerate(self.padState):
             # mixerpad 0 = background
             mixerpad = (self.mixingPipeline
-                            .get_by_name('mix')
-                            .get_static_pad('sink_%u' % (idx + 1)))
+                        .get_by_name('mix')
+                        .get_static_pad('sink_%u' % (idx + 1)))
+
+            cropper = self.mixingPipeline.get_by_name("video_%u_cropper" % idx)
 
             self.log.debug('Reconfiguring Mixerpad %u to '
                            'x/y=%u/%u, w/h=%u/%u alpha=%0.2f, zorder=%u',
@@ -341,6 +398,17 @@ class VideoMix(object):
             mixerpad.set_property('alpha', state.alpha)
             mixerpad.set_property('zorder', state.zorder)
 
+            self.log.info("Reconfiguring Cropper %d to %d/%d/%d/%d",
+                          idx,
+                          state.croptop,
+                          state.cropleft,
+                          state.cropbottom,
+                          state.cropright)
+            cropper.set_property("top", state.croptop)
+            cropper.set_property("left", state.cropleft)
+            cropper.set_property("bottom", state.cropbottom)
+            cropper.set_property("right", state.cropright)
+
     def selectCompositeModeDefaultSources(self):
         sectionNames = {
             CompositeModes.fullscreen: 'fullscreen',
@@ -405,10 +473,12 @@ class VideoMix(object):
     def getVideoSourceB(self):
         return self.sourceB
 
-    def setCompositeMode(self, mode):
+    def setCompositeMode(self, mode, apply_default_source=True):
         self.compositeMode = mode
 
-        self.selectCompositeModeDefaultSources()
+        if apply_default_source:
+            self.selectCompositeModeDefaultSources()
+
         self.recalculateMixerState()
 
     def getCompositeMode(self):
