@@ -7,10 +7,9 @@ import sys
 # import GStreamer and GLib-Helper classes
 gi.require_version('Gst', '1.0')
 gi.require_version('GstNet', '1.0')
-from gi.repository import Gst, GstNet, GObject
+from gi.repository import Gst, GObject
 
 # import local classes
-from lib.args import Args
 from lib.loghandler import LogHandler
 
 # check min-version
@@ -66,9 +65,13 @@ class Voctocore(object):
 
 # run mainclass
 def main():
-    # configure logging
-    docolor = (Args.color == 'always') or (Args.color == 'auto' and
-                                           sys.stderr.isatty())
+    # parse command-line args
+    from lib import args
+    args.parse()
+
+    from lib.args import Args
+    docolor = (Args.color == 'always') \
+        or (Args.color == 'auto' and sys.stderr.isatty())
 
     handler = LogHandler(docolor, Args.timestamp)
     logging.root.addHandler(handler)
@@ -89,6 +92,10 @@ def main():
     logging.info('Python Version: %s', sys.version_info)
     logging.info('GStreamer Version: %s', Gst.version())
 
+    logging.debug('loading Config')
+    from lib import config
+    config.load()
+
     # init main-class and main-loop
     logging.debug('initializing Voctocore')
     voctocore = Voctocore()
@@ -96,5 +103,10 @@ def main():
     logging.debug('running Voctocore')
     voctocore.run()
 
+
 if __name__ == '__main__':
-    main()
+    try:
+        main()
+    except RuntimeError as e:
+        logging.error(str(e))
+        sys.exit(1)
