@@ -1,59 +1,81 @@
 import logging
+
 from gi.repository import Gtk
+import lib.connection as Connection
 
 from lib.config import Config
-import lib.connection as Connection
 
 
 class StreamblankToolbarController(object):
     """Manages Accelerators and Clicks on the Composition Toolbar-Buttons"""
 
-    def __init__(self, drawing_area, win, uibuilder, warning_overlay):
+    def __init__(self, toolbar, win, uibuilder, warning_overlay):
         self.log = logging.getLogger('StreamblankToolbarController')
 
         self.warning_overlay = warning_overlay
 
-        livebtn = uibuilder.find_widget_recursive(drawing_area, 'stream_live')
-        blankbtn = uibuilder.find_widget_recursive(drawing_area,
-                                                   'stream_blank')
+        accelerators = Gtk.AccelGroup()
+        win.add_accel_group(accelerators)
 
-        blankbtn_pos = drawing_area.get_item_index(blankbtn)
+        livebtn = uibuilder.find_widget_recursive(toolbar, 'stream_live')
+        blankbtn = uibuilder.find_widget_recursive(toolbar, 'stream_blank')
+
+        blankbtn_pos = toolbar.get_item_index(blankbtn)
 
         if not Config.getboolean('stream-blanker', 'enabled'):
             self.log.info('disabling stream-blanker features '
                           'because the server does not support them: %s',
                           Config.getboolean('stream-blanker', 'enabled'))
 
-            drawing_area.remove(livebtn)
-            drawing_area.remove(blankbtn)
+            toolbar.remove(livebtn)
+            toolbar.remove(blankbtn)
             return
 
         blank_sources = Config.getlist('stream-blanker', 'sources')
-        self.status_btns = {}
 
         self.current_status = None
 
+        key, mod = Gtk.accelerator_parse('F12')
         livebtn.connect('toggled', self.on_btn_toggled)
         livebtn.set_name('live')
+        livebtn.set_label(livebtn.get_label() + "\nF12")
+
+        tooltip = Gtk.accelerator_get_label(key, mod)
+        livebtn.set_tooltip_text(tooltip)
+
+        livebtn.get_child().add_accelerator('clicked', accelerators,
+                                            key, mod, Gtk.AccelFlags.VISIBLE)
 
         self.livebtn = livebtn
         self.blank_btns = {}
 
+        accel_f_key = 11
+
         for idx, name in enumerate(blank_sources):
+            key, mod = Gtk.accelerator_parse('F%u' % accel_f_key)
+
             if idx == 0:
                 new_btn = blankbtn
             else:
                 new_icon = Gtk.Image.new_from_pixbuf(blankbtn.get_icon_widget()
-                                                             .get_pixbuf())
+                                                     .get_pixbuf())
                 new_btn = Gtk.RadioToolButton(group=livebtn)
                 new_btn.set_icon_widget(new_icon)
-                drawing_area.insert(new_btn, blankbtn_pos + 1)
+                toolbar.insert(new_btn, blankbtn_pos)
 
-            new_btn.set_label("Stream %s" % name)
+            new_btn.set_label("Stream %s\nF%s" % (name, accel_f_key))
             new_btn.connect('toggled', self.on_btn_toggled)
             new_btn.set_name(name)
 
+            tooltip = Gtk.accelerator_get_label(key, mod)
+            new_btn.set_tooltip_text(tooltip)
+
+            new_btn.get_child().add_accelerator(
+                'clicked', accelerators,
+                key, mod, Gtk.AccelFlags.VISIBLE)
+
             self.blank_btns[name] = new_btn
+            accel_f_key = accel_f_key - 1
 
         # connect event-handler and request initial state
         Connection.on('stream_status', self.on_stream_status)
