@@ -1,6 +1,5 @@
-import gi
 import logging
-from gi.repository import Gtk, Gst, Gdk, GLib
+from gi.repository import Gtk, Gdk
 
 from lib.config import Config
 from lib.uibuilder import UiBuilder
@@ -10,12 +9,15 @@ from lib.audioleveldisplay import AudioLevelDisplay
 from lib.warningoverlay import VideoWarningOverlay
 
 from lib.videopreviews import VideoPreviewsController
-from lib.audioselector import AudioSelectorController
 
 from lib.toolbar.composition import CompositionToolbarController
 from lib.toolbar.streamblank import StreamblankToolbarController
 from lib.toolbar.misc import MiscToolbarController
 
+from lib.shortcuts import show_shortcuts
+
+from lib.studioclock import StudioClock
+
 
 class Ui(UiBuilder):
 
@@ -29,13 +31,31 @@ class Ui(UiBuilder):
         # Aquire the Main-Window from the UI-File
         self.win = self.get_check_widget('window')
 
+        # check for configuration option mainwindow/force_fullscreen
+        if Config.getboolean('mainwindow', 'forcefullscreen', fallback=False):
+            self.log.info(
+                'Forcing main window to full screen by configuration')
+            # set window into fullscreen mode
+            self.win.fullscreen()
+        else:
+            # check for configuration option mainwindow/width and /height
+            if Config.has_option('mainwindow', 'width') \
+                    and Config.has_option('mainwindow', 'height'):
+                # get size from config
+                width = Config.getint('mainwindow', 'width')
+                height = Config.getint('mainwindow', 'height')
+                self.log.info(
+                    'Set window size by configuration to %d:%d', width, height)
+                # set window size
+                self.win.set_size_request(width, height)
+                self.win.set_resizable(False)
+
         # Connect Close-Handler
         self.win.connect('delete-event', Gtk.main_quit)
 
-        # Create Audio-Level Display
-        drawing_area = self.find_widget_recursive(self.win, 'audiolevel_main')
-        self.audio_level_display = AudioLevelDisplay(drawing_area)
-
+        # Get Audio-Level Display
+        self.audio_level_display = self.find_widget_recursive(
+            self.win, 'audiolevel_main')
         # Create Main-Video Overlay Controller
         drawing_area = self.find_widget_recursive(self.win,
                                                   'video_overlay_drawingarea')
@@ -51,24 +71,13 @@ class Ui(UiBuilder):
         )
 
         # Setup Preview Controller
-        drawing_area = self.find_widget_recursive(self.win, 'box_left')
+        box_left = self.find_widget_recursive(self.win, 'box_left')
         self.video_previews_controller = VideoPreviewsController(
-            drawing_area,
+            box_left,
             win=self.win,
             uibuilder=self
         )
 
-        # check if there is a fixed audio source configured.
-        # if so, remove the combo-box entirely instead of setting it up.
-        if Config.has_option('mix', 'audiosource'):
-            drawing_area.remove(self.find_widget_recursive(self.win, 'box_audio'))
-        else:
-            self.audio_selector_controller = AudioSelectorController(
-                drawing_area=self.find_widget_recursive(self.win, 'combo_audio'),
-                win=self.win,
-                uibuilder=self
-            )
-
         # Setup Toolbar Controllers
         toolbar = self.find_widget_recursive(self.win, 'toolbar')
         self.composition_toolbar_controller = CompositionToolbarController(
@@ -90,6 +99,20 @@ class Ui(UiBuilder):
             uibuilder=self
         )
 
+        # Setup Shortcuts window
+        self.win.connect('key-press-event', self.handle_keypress)
+        self.win.connect('window-state-event', self.handle_state)
+
+    def handle_keypress(self, window, event):
+        if event.keyval == Gdk.KEY_question:
+            show_shortcuts(window)
+
+    def handle_state(self, window, event):
+        # force full screen if whished by configuration
+        if Config.getboolean('mainwindow', 'forcefullscreen', fallback=False):
+            self.log.info('re-forcing fullscreen mode')
+            self.win.fullscreen()
+
     def show(self):
         self.log.info('Showing Main-Window')
         self.win.show_all()
