@@ -31,21 +31,14 @@ GObject.threads_init()
 Gdk.init([])
 Gtk.init([])
 
-# import local classes
-from lib.args import Args
-from lib.config import Config
-from lib.ui import Ui
-from lib.loghandler import LogHandler
-
-import lib.connection as Connection
-import lib.clock as ClockManager
-
 
 # main class
 class Voctogui(object):
 
     def __init__(self):
         self.log = logging.getLogger('Voctogui')
+        from lib.args import Args
+        from lib.ui import Ui
 
         # Uf a UI-File was specified on the Command-Line, load it
         if Args.ui_file:
@@ -76,6 +69,36 @@ class Voctogui(object):
             raise Exception("Can't find any .ui-Files to use "
                             "(searched {})".format(', '.join(paths)))
 
+        #
+        # search for a .css style sheet file and load it
+        #
+
+        css_provider = Gtk.CssProvider()
+        context = Gtk.StyleContext()
+
+        css_paths = [
+            os.path.join(os.path.dirname(os.path.realpath(__file__)),
+                         'ui/voctogui.css'),
+            '/usr/lib/voctogui/ui/voctogui.css'
+        ]
+
+        for path in css_paths:
+            self.log.debug('trying to load css-file from file %s', path)
+
+            if os.path.isfile(path):
+                self.log.info('loading css-file from file %s', path)
+                css_provider.load_from_path(path)
+                break
+        else:
+            raise Exception("Can't find any .css-Files to use "
+                            "(searched {})".format(', '.join(css_paths)))
+
+        context.add_provider_for_screen(
+            Gdk.Screen.get_default(),
+            css_provider,
+            Gtk.STYLE_PROVIDER_PRIORITY_USER
+        )
+
         self.ui.setup()
 
     def run(self):
@@ -96,10 +119,15 @@ class Voctogui(object):
 
 # run mainclass
 def main():
-    # configure logging
-    docolor = (Args.color == 'always') or (Args.color == 'auto' and
-                                           sys.stderr.isatty())
+    # parse command-line args
+    from lib import args
+    args.parse()
 
+    from lib.args import Args
+    docolor = (Args.color == 'always') \
+        or (Args.color == 'auto' and sys.stderr.isatty())
+
+    from lib.loghandler import LogHandler
     handler = LogHandler(docolor, Args.timestamp)
     logging.root.addHandler(handler)
 
@@ -119,7 +147,14 @@ def main():
     logging.info('Python Version: %s', sys.version_info)
     logging.info('GStreamer Version: %s', Gst.version())
 
+    logging.debug('loading Config')
+    from lib import config
+    config.load()
+
+    from lib.config import Config
+
     # establish a synchronus connection to server
+    import lib.connection as Connection
     Connection.establish(
         Args.host if Args.host else Config.get('server', 'host')
     )
@@ -131,13 +166,13 @@ def main():
     # The list-comparison is not complete
     # (one could use a local hostname or the local system ip),
     # but it's only here to warn that one might be making a mistake
-    use_previews = (Config.getboolean('previews', 'enabled') and
-                    Config.getboolean('previews', 'use'))
+    use_previews = Config.getboolean('previews', 'enabled') \
+        and Config.getboolean('previews', 'use')
     looks_like_localhost = Config.get('server', 'host') in ['::1',
                                                             '127.0.0.1',
                                                             'localhost']
     if not use_previews and not looks_like_localhost:
-        logging.warn(
+        logging.warning(
             'Connecting to `%s` (which looks like a remote host) '
             'might not work without enabeling the preview encoders '
             '(set `[previews] enabled=true` on the core) or it might saturate '
@@ -145,6 +180,9 @@ def main():
             Config.get('server', 'host')
         )
 
+    import lib.connection as Connection
+    import lib.clock as ClockManager
+
     # obtain network-clock
     ClockManager.obtainClock(Connection.ip)
 
@@ -160,5 +198,10 @@ def main():
     logging.debug('running Voctogui')
     voctogui.run()
 
+
 if __name__ == '__main__':
-    main()
+    try:
+        main()
+    except RuntimeError as e:
+        logging.error(str(e))
+        sys.exit(1)
